To do list
----------

1. (package) Expand automated testing
4. (tidepool) Implement ASPECTS/JHU averaging
7. (rapidtide) Implement a dispersive delay model
8. (rapidtide) Add a sinc peak fit
9. (tidepool) Fix the weird limit resetting bug when some panes are activated.
10. (tidepool)

Implement new argument parsing:
vi \
rapidtide/scripts/showxcorr_legacy.py \
rapidtide/scripts/threeD.py \
rapidtide/experimental/highresmotion \
rapidtide/experimental/harmonogram \
rapidtide/workflows/rapidtide2x_parser.py
